@@ -16,18 +16,31 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.1 2004/01/15 16:54:39 chpe Exp $
+ *  $Id: sample-mozilla.c,v 1.2.2.1 2004/09/26 16:22:39 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-sample2-extension.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
+#include <glib/gi18n-lib.h>
+
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
 
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
 	LOG ("Registering EphySampleExtension")
 
+#ifdef ENABLE_NLS
+       /* Initialise the i18n stuff */
+        bindtextdomain (GETTEXT_PACKAGE, EPHY_PLUGINS_LOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
+#endif /* ENABLE_NLS */
+
 	return ephy_sample2_extension_register_type (module);
 }
